@@ -33,23 +33,26 @@ class APIRequestor(object):
             return sorts
 
     def request(self, method, url, headers=None, body=None, params=None, api_key=None):
+        if api_key is None:
+            token = self._get_token()
+        else:
+            token = api_key
+
+        abs_url = "{base_url}/{url}".format(base_url=api_base, url=url)
+
+        return self.request_base(method=method, url=abs_url, headers=headers, body=body, params=params, api_key=token)
+
+    def request_base(self, method, url, headers=None, body=None, params=None, api_key=None):
         if method not in ['GET', 'POST', 'PUT', 'DELETE', 'PATCH']:
             raise APIConnectionError(
                 "Unrecognized HTTP method {method}. This may indicate a bug in the Whatify "
                 "internal bindings. Please contact support for assistance.".format(method=method)
             )
 
-        if api_key is None:
-            token = self._get_token()
-        else:
-            token = api_key
-
         rheaders = self._build_headers()
         rheaders.update(**(headers or {}))
-
-        params = {'jwt': token, **(params or {})}
-        abs_url = "{base_url}/{url}".format(base_url=api_base, url=url)
-        response = self._http_client.request(method=method, url=abs_url, headers=rheaders, json=body, params=params)
+        params = {'jwt': api_key, **(params or {})}
+        response = self._http_client.request(method=method, url=url, headers=rheaders, json=body, params=params)
         return self._handle_response(response)
 
     def post(self, url, headers=None, body=None, params=None, api_key=None):
