@@ -111,7 +111,7 @@ class MyWhatify:
         '''
             set our default store for testing
         '''
-        cls.set_magento_api(magento2url='http://whatify.tempurl.co.il/whatify/api/db/table/sales_order/limit/3/page/1/',
+        cls.set_magento_api(magento2url='http://whatify.tempurl.co.il/whatify/api/db/',
                             magento_header={'Whatify-Merchant-ID': 'j458vgjeDVHe564y3435',
                                             'Whatify-API-Key': 'n6hcr4_6beuvthg45vw_3v5te5yb565454vbn'})
 
@@ -181,7 +181,7 @@ class MyWhatify:
         base_url = base_url[:-1]
 
         ret_json = cls.base_api(url=base_url, method=api_method, headers=cls.magento_headers, body=body)
-        retval = pd.DataFrame.from_dict(ret_json.to_dict(), orient='columns')
+        retval = pd.DataFrame.from_dict(ret_json['data'], orient='columns')
         return retval
 
     #############################
